<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>EventDialog</name>
    <message>
        <source>Event Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>House event</source>
        <extracomment>Constant event w/ Boolean state value</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic event</source>
        <extracomment>The main analysis event (e.g., component failure)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undeveloped</source>
        <extracomment>The basic event flavor that indicates the further developement into a gate is possible.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conditional</source>
        <extracomment>Conditioning flavor for a basic event (used as a conditioning variable for conditional probabilities)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gate</source>
        <extracomment>The intermediary w/ a Boolean formula as a definition. Defines the logic and interdependencies of the fault tree.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>False</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>True</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connective:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AND</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ATLEAST</source>
        <extracomment>VOTE, Voting OR, Combo, Combination, K/N gate</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XOR</source>
        <extracomment>Exclusive OR</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NOT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAND</source>
        <extracomment>NOT AND</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NOR</source>
        <extracomment>NOT OR</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Min:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add argument with its ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Argument</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Argument</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fault tree:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant</source>
        <comment>constant probability value</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exponential</source>
        <comment>probability type defined w/ negative exponential formula</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NULL</source>
        <comment>Not a null value.</comment>
        <extracomment>Pass-through, NO-OP type</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Analysis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Model Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Analysis Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About the Qt toolkit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;SCRAM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit the Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a New Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open Model Files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Model Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Model &amp;As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Export As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run Analysis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Analysis Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Previe&amp;w...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add Element</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re&amp;move Element</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export &amp;Report As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re&amp;name Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <comment>execute analysis</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings...</source>
        <comment>analysis configuration</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent &amp;Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear List</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NameDialog</name>
    <message>
        <source>Name Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo limit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-save:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>min</source>
        <extracomment>Shortened time unit for &apos;minutes&apos;</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Set element &apos;%1&apos; label to &apos;%2&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify basic event &apos;%1&apos; expression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set house event &apos;%1&apos; state to &apos;%2&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update gate &apos;%1&apos; formula</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename model to &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add fault tree &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove fault tree &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename event &apos;%1&apos; to &apos;%2&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>True</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>False</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add event &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove event &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change the type of event &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IO Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MEF Container: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML element: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML attribute: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Analysis Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Approximations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rare-event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Analyses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prime implicants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Algorithms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mission time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Product order:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Start Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start a New Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Model Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Example Models</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::DiagramView</name>
    <message>
        <source>Export As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SVG files (*.svg);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::EventDialog</name>
    <message>
        <source>House event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The argument &apos;%1&apos; is already in formula.</source>
        <extracomment>Duplicate arguments are not allowed in a formula.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The argument &apos;%1&apos; would introduce a self-cycle.</source>
        <extracomment>Self-cycle is also called a loop in a graph.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The argument &apos;%1&apos; would introduce a cycle.</source>
        <extracomment>Fault trees are acyclic graphs.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The event with name &apos;%1&apos; already exists.</source>
        <extracomment>Duplicate event definition in the model.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name &apos;%1&apos; would introduce a self-cycle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 connective requires a single argument.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 connective requires 2 or more arguments.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 connective requires exactly 2 arguments.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fault tree &apos;%1&apos; is already defined with a top gate.</source>
        <extracomment>Fault tree redefinition.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%1 connective requires at-least %n arguments.</source>
        <extracomment>The number of required arguments is always more than 2.</extracomment>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>scram::gui::MainWindow</name>
    <message>
        <source>Validation Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not all basic events have expressions for probability analysis.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running analysis...</source>
        <extracomment>This is a message shown during the analysis run.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initialization Error</source>
        <extracomment>The error upon initialization from a file.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fault tree &apos;%1&apos; must have a single top-gate.</source>
        <extracomment>Single top/root event fault tree are expected by GUI.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find/Filter (Perl Regex)</source>
        <extracomment>The search bar.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About SCRAM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Model?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save changes to model &apos;%1&apos; before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Model Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Model Exchange Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Model As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Report As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dependency Container Removal</source>
        <extracomment>The container w/ dependents still in the model.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fault tree &apos;%1&apos; with root &apos;%2&apos; is not removable because it has dependent non-root gates. Remove the gates from the fault tree before this operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove fault tree &apos;%1&apos; with root &apos;%2&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dependency Event Removal</source>
        <extracomment>The event w/ dependents in the model.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event &apos;%1&apos; is not removable because it has dependents. Remove the event from the dependents before this operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add fault tree &apos;%1&apos; with gate &apos;%2&apos;</source>
        <extracomment>Addition of a fault by defining its root event first.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gates</source>
        <extracomment>The tab for the table of gates.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic Events</source>
        <extracomment>The tab for the table of basic events.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>House Events</source>
        <extracomment>The tab for the table of house events.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fault Tree: %1</source>
        <extracomment>The tab for a fault tree diagram.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Products: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importance: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;h1&gt;SCRAM %1&lt;/h1&gt;The GUI front-end for SCRAM,&lt;br/&gt;a command-line risk analysis multi-tool.&lt;br/&gt;&lt;br/&gt;License: GPLv3+&lt;br/&gt;Homepage: &lt;a href=&quot;%2&quot;&gt;%2&lt;/a&gt;&lt;br/&gt;Technical Support: &lt;a href=&quot;%3&quot;&gt;%3&lt;/a&gt;&lt;br/&gt;Bug Tracker: &lt;a href=&quot;%4&quot;&gt;%4&lt;/a&gt;&lt;br/&gt;&lt;br/&gt;%5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration file error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML Validity Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid configuration file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input file error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid input file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid input model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unnamed Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save error</source>
        <comment>error on saving to file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reporting error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::ModelTree</name>
    <message>
        <source>Fault Trees (%L1)</source>
        <extracomment>The parent item for collections of fault trees in the model.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gates (%L1)</source>
        <extracomment>The table of gates.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic Events (%L1)</source>
        <extracomment>The table of basic events.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>House Events (%L1)</source>
        <extracomment>The table of house events.</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::PreferencesDialog</name>
    <message>
        <source>Restart Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The language change will take effect after an application restart.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::ReportTree</name>
    <message>
        <source>Products (%L1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probability (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importance Factors (%L1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::model::BasicEvent</name>
    <message>
        <source>Set basic event &apos;%1&apos; flavor to &apos;%2&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undeveloped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conditional</source>
        <extracomment>Actually, this is &apos;conditioning&apos; since the event is the condition for some sub-tree.</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::model::BasicEventContainerModel</name>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flavor</source>
        <extracomment>The flavor type of a basic event.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probability</source>
        <extracomment>In PRA context, probability may be unavailability or unreliability.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::model::Gate</name>
    <message>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at-least %1</source>
        <extracomment>Also named as &apos;vote&apos;, &apos;voting or&apos;, &apos;combination&apos;, &apos;combo&apos;.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>xor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>not</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>null</source>
        <extracomment>This is &apos;pass-through&apos; or &apos;no-action&apos; gate type.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nand</source>
        <extracomment>not and.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nor</source>
        <extracomment>not or.</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::model::GateContainerModel</name>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connective</source>
        <extracomment>Boolean operator of the Boolean formula.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Args</source>
        <extracomment>The number of arguments in the Boolean formula.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::model::HouseEventContainerModel</name>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State</source>
        <extracomment>House event Boolean state.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::model::ImportanceTableModel</name>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Occurrence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MIF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CIF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DIF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RAW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RRW</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>scram::gui::model::ProductTableModel</name>
    <message>
        <source>Product</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contribution</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
